;; Generated package description from sml-mode.el  -*- no-byte-compile: t -*-
(define-package "sml-mode" "6.10.0.20201201.100114" "Major mode for editing (Standard) ML" '((emacs "24.3") (cl-lib "0.5")) :url "https://elpa.gnu.org/packages/sml-mode.html" :authors '(("Lars Bo Nielsen") ("	Olin Shivers") ("	Fritz Knabe (?)") ("	Steven Gilmore (?)") ("	Matthew Morley" . "mjm@scs.leeds.ac.uk") ("	Matthias Blume" . "blume@cs.princeton.edu") ("	(Stefan Monnier)" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca") :keywords '("sml"))
